@@ -1,28 +1,27 @@
 from django.http import HttpResponseBadRequest, JsonResponse
 from django.template.loader import render_to_string
 
-from debug_toolbar.decorators import require_show_toolbar, signed_data_view
-from debug_toolbar.forms import SignedDataForm
+from debug_toolbar.decorators import require_show_toolbar
 from debug_toolbar.panels.history.forms import HistoryStoreForm
 from debug_toolbar.toolbar import DebugToolbar
 
 
 @require_show_toolbar
-@signed_data_view
-def history_sidebar(request, verified_data):
+def history_sidebar(request):
     """Returns the selected debug toolbar history snapshot."""
-    form = HistoryStoreForm(verified_data)
+    form = HistoryStoreForm(request.GET)
 
     if form.is_valid():
         store_id = form.cleaned_data["store_id"]
         toolbar = DebugToolbar.fetch(store_id)
+        exclude_history = form.cleaned_data["exclude_history"]
         context = {}
         if toolbar is None:
             # When the store_id has been popped already due to
             # RESULTS_CACHE_SIZE
             return JsonResponse(context)
         for panel in toolbar.panels:
-            if not panel.is_historical:
+            if exclude_history and not panel.is_historical:
                 continue
             panel_context = {"panel": panel}
             context[panel.panel_id] = {
@@ -38,15 +37,14 @@ def history_sidebar(request, verified_data):
 
 
 @require_show_toolbar
-@signed_data_view
-def history_refresh(request, verified_data):
+def history_refresh(request):
     """Returns the refreshed list of table rows for the History Panel."""
-    form = HistoryStoreForm(verified_data)
+    form = HistoryStoreForm(request.GET)
 
     if form.is_valid():
         requests = []
-        # Convert to list to handle mutations happenening in parallel
-        for id, toolbar in list(DebugToolbar._store.items())[::-1]:
+        # Convert to list to handle mutations happening in parallel
+        for id, toolbar in list(DebugToolbar._store.items()):
             requests.append(
                 {
                     "id": id,
@@ -56,10 +54,11 @@ def history_refresh(request, verified_data):
                             "id": id,
                             "store_context": {
                                 "toolbar": toolbar,
-                                "form": SignedDataForm(
-                                    initial=HistoryStoreForm(
-                                        initial={"store_id": id}
-                                    ).initial
+                                "form": HistoryStoreForm(
+                                    initial={
+                                        "store_id": id,
+                                        "exclude_history": True,
+                                    }
                                 ),
                             },
                         },
